@@ -2,10 +2,9 @@
 
 use core::ptr::{null, null_mut};
 
-use crate::ffi::sigset_t;
 use crate::{
     cstring, error, error_ref_mut, rstring, NcAlign, NcBlitter, NcCapabilities, NcChannels,
-    NcComponent, NcDim, NcDirect, NcDirectFlags, NcEgc, NcError, NcInput, NcOffset, NcPaletteIndex,
+    NcComponent, NcDim, NcDirect, NcDirectFlags, NcError, NcInput, NcOffset, NcPaletteIndex,
     NcPlane, NcResult, NcRgb, NcScale, NcStyle, NcTime, NCRESULT_ERR,
 };
 
@@ -556,33 +555,16 @@ impl NcDirect {
     /// Provide a None `time` to block at length, a `time` of 0 for non-blocking
     /// operation, and otherwise a timespec to bound blocking.
     ///
-    /// Signals in sigmask (less several we handle internally) will be atomically
-    /// masked and unmasked per [ppoll(2)](https://linux.die.net/man/2/ppoll).
-    ///
-    /// `*sigmask` should generally contain all signals.
-    ///
     /// *C style function: [ncdirect_getc()][crate::ncdirect_getc].*
     //
     // CHECK returns 0 on a timeout.
-    pub fn getc(
-        &mut self,
-        time: Option<NcTime>,
-        sigmask: Option<&mut sigset_t>,
-        input: Option<&mut NcInput>,
-    ) -> NcResult<char> {
+    pub fn getc(&mut self, time: Option<NcTime>, input: Option<&mut NcInput>) -> NcResult<char> {
         let ntime;
         if let Some(time) = time {
             ntime = &time as *const _;
         } else {
             ntime = null();
         }
-
-        let nsigmask;
-        if let Some(sigmask) = sigmask {
-            nsigmask = sigmask as *mut _;
-        } else {
-            nsigmask = null_mut() as *mut _;
-        }
         let ninput;
         if let Some(input) = input {
             ninput = input as *mut _;
@@ -590,7 +572,7 @@ impl NcDirect {
             ninput = null_mut();
         }
         let c = unsafe {
-            core::char::from_u32_unchecked(crate::ncdirect_getc(self, ntime, nsigmask, ninput))
+            core::char::from_u32_unchecked(crate::ncdirect_getc(self, ntime, null_mut(), ninput))
         };
         if c as u32 as i32 == NCRESULT_ERR {
             return Err(NcError::new());
@@ -740,12 +722,13 @@ impl NcDirect {
             crate::ncdirect_rounded_box(self, ul, ur, ll, lr, y_len as i32, x_len as i32, ctlword)
         }]
     }
+
     /// Draws horizontal lines using the specified [NcChannels]s, interpolating
     /// between them as we go.
     ///
     /// All lines start at the current cursor position.
     ///
-    /// The [NcEgc] at `egc` may not use more than one column.
+    /// The string at `egc` may not use more than one column.
     ///
     /// For a horizontal line, `len` cannot exceed the screen width minus the
     /// cursor's offset.
@@ -754,18 +737,12 @@ impl NcDirect {
     #[inline]
     pub fn hline_interp(
         &mut self,
-        egc: &NcEgc,
+        egc: &str,
         len: NcDim,
         h1: NcChannels,
         h2: NcChannels,
     ) -> NcResult<()> {
-        // https://github.com/dankamongmen/notcurses/issues/1339
-        #[cfg(any(target_arch = "x86_64", target_arch = "i686"))]
-        let egc_ptr = &(*egc as i8);
-        #[cfg(not(any(target_arch = "x86_64", target_arch = "i686")))]
-        let egc_ptr = &(*egc as u8);
-
-        error![unsafe { crate::ncdirect_hline_interp(self, egc_ptr, len as i32, h1, h2) }]
+        error![crate::ncdirect_hline_interp(self, egc, len, h1, h2)]
     }
 
     /// Draws horizontal lines using the specified [NcChannels]s, interpolating
@@ -773,7 +750,7 @@ impl NcDirect {
     ///
     /// All lines start at the current cursor position.
     ///
-    /// The [NcEgc] at `egc` may not use more than one column.
+    /// The string at `egc` may not use more than one column.
     ///
     /// For a vertical line, `len` may be as long as you'd like; the screen
     /// will scroll as necessary.
@@ -782,17 +759,11 @@ impl NcDirect {
     #[inline]
     pub fn vline_interp(
         &mut self,
-        egc: &NcEgc,
+        egc: &str,
         len: NcDim,
         h1: NcChannels,
         h2: NcChannels,
     ) -> NcResult<()> {
-        // https://github.com/dankamongmen/notcurses/issues/1339
-        #[cfg(any(target_arch = "x86_64", target_arch = "i686"))]
-        let egc_ptr = &(*egc as i8);
-        #[cfg(not(any(target_arch = "x86_64", target_arch = "i686")))]
-        let egc_ptr = &(*egc as u8);
-
-        error![unsafe { crate::ncdirect_vline_interp(self, egc_ptr, len as i32, h1, h2) }]
+        error![crate::ncdirect_vline_interp(self, egc, len, h1, h2)]
     }
 }
